Skip to contents

Create Age Plot

Usage

plot_Ages(
  object,
  sample_names = NULL,
  sample_order = NULL,
  plot_mode = "ages",
  model = "Baylum",
  ...
)

Arguments

object

list or data.frame (required): Output as created by functions like AgeC14_Computation, which is a list of class BayLum.list. Alternatively the function supports a data.frame as input, however, in such a case the data.frame must resemble the ages data.frame created by the computation functions otherwise the input will be silently ignored.

sample_names

character (optional): alternative sample names used for the plotting. If the length of the provided character vector is shorter than the real number of samples, the names are recycled.

sample_order

numeric (optional): argument to rearrange the sample order, e.g., sample_order = c(4:1) plots the last sample first.

plot_mode

character (with default): allows to switch from displaying ages as points with lines ("ages") for the credible intervals to densities ("density")

model

character "BayLum" by default. Name of the used Bayesian Age model (see ModelAgePrior).

...

further arguments to control the plot output, standard arguments are: cex, xlim, main, xlab, col further (non-standard) arguments are: grid (TRUE/FALSE), legend (TRUE/FALSE), legend.text (character input needed), legend.pos graphics::legend, legend.cex. Additional arguments: d_scale (scales density plots), show_ages (add ages to density plots)

Value

The function returns a plot and the data.frame used to display the data

Details

This function creates an age plot showing the mean ages along with the credible intervals. The function provides various arguments to modify the plot output, however, for an ultimate control the function returns the data.frame extracted from the input object for own plots.

Function version

0.1.5

Author

Sebastian Kreutzer, Institute of Geography, Ruprecht-Karl-University of Heidelberg (Germany), based on code written by Claire Christophe

Examples

## load data
data(DATA_C14,envir = environment())
C14Cal <- DATA_C14$C14[,1]
SigmaC14Cal <- DATA_C14$C14[,2]
Names <- DATA_C14$Names
nb_sample <- length(Names)

## Age computation
Age <- AgeC14_Computation(
   Data_C14Cal = C14Cal,
   Data_SigmaC14Cal = SigmaC14Cal,
   SampleNames = Names,
   Nb_sample = nb_sample,
   PriorAge = rep(c(20,60),nb_sample),
   Iter = 500,
   quiet = TRUE)
#> Finished running the simulation
#> Warning: [plot_MCMC()] Argument 'n.iter' out of range, reset to number of observations in mcmc.list / mcmc




#> 
#> 
#> >> MCMC Convergence of Age parameters <<
#> ----------------------------------------------
#> Sample name   Bayes estimate   Uppers credible interval
#> A_S-EVA-26510 	 1.001 		 1.004 
#> A_S-EVA-26506 	 1.004 		 1.005 
#> A_S-EVA-26507 	 1.01 		 1.022 
#> A_S-EVA-26508 	 1.004 		 1.011 
#> 
#> 
#> ---------------------------------------------------------------------------------------------------
#>  *** WARNING: The following information are only valid if the MCMC chains have converged  ***
#> ---------------------------------------------------------------------------------------------------
#> 
#> 
#> 
#> >> Bayes estimates of Age for each sample and credible interval <<
#> ------------------------------------------------------
#> Sample name 	 Bayes estimate  Credible interval: 
#> A_S-EVA-26510 	 41.960961204292 
#> 						 lower bound 	 upper bound
#> 				 at level 95% 	 41.457 		 42.331 
#> 				 at level 68% 	 41.813 		 42.227 
#> ------------------------------------------------------
#> Sample name 	 Bayes estimate  Credible interval: 
#> A_S-EVA-26506 	 45.7045043812265 
#> 						 lower bound 	 upper bound
#> 				 at level 95% 	 45.039 		 46.291 
#> 				 at level 68% 	 45.416 		 45.976 
#> ------------------------------------------------------
#> Sample name 	 Bayes estimate  Credible interval: 
#> A_S-EVA-26507 	 44.8464847725795 
#> 						 lower bound 	 upper bound
#> 				 at level 95% 	 43.686 		 45.902 
#> 				 at level 68% 	 44.391 		 45.303 
#> ------------------------------------------------------
#> Sample name 	 Bayes estimate  Credible interval: 
#> A_S-EVA-26508 	 45.0530562099889 
#> 						 lower bound 	 upper bound
#> 				 at level 95% 	 43.964 		 46.121 
#> 				 at level 68% 	 44.502 		 45.466 
#> 
#> ------------------------------------------------------



## plot output
plot_Ages(Age)

#>        SAMPLE      AGE HPD68.MIN HPD68.MAX HPD95.MIN HPD95.MAX ALT_SAMPLE_NAME
#> 1 S-EVA-26510 41.96096    41.813    42.227    41.457    42.331              NA
#> 2 S-EVA-26506 45.70450    45.416    45.976    45.039    46.291              NA
#> 3 S-EVA-26507 44.84648    44.391    45.303    43.686    45.902              NA
#> 4 S-EVA-26508 45.05306    44.502    45.466    43.964    46.121              NA
#>   AT
#> 1  4
#> 2  3
#> 3  2
#> 4  1

## plot output
plot_Ages(Age, plot_mode = "density", legend.pos = "topright")

#>        SAMPLE      AGE HPD68.MIN HPD68.MAX HPD95.MIN HPD95.MAX ALT_SAMPLE_NAME
#> 1 S-EVA-26510 41.96096    41.813    42.227    41.457    42.331              NA
#> 2 S-EVA-26506 45.70450    45.416    45.976    45.039    46.291              NA
#> 3 S-EVA-26507 44.84648    44.391    45.303    43.686    45.902              NA
#> 4 S-EVA-26508 45.05306    44.502    45.466    43.964    46.121              NA
#>   AT
#> 1  4
#> 2  3
#> 3  2
#> 4  1